@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -14,30 +14,30 @@
 
 /* Table of constant values */
 
+static logical c_true = TRUE_;
 static logical c_false = FALSE_;
 static integer c__200 = 200;
 static integer c__800 = 800;
 static integer c__400 = 400;
 static integer c__3 = 3;
 static integer c__1 = 1;
-static logical c_true = TRUE_;
-static real c_b28 = 1.f;
-static real c_b29 = .5f;
+static real c_b30 = 1.f;
+static real c_b31 = .5f;
 static integer c__65341 = 65341;
 static integer c__73 = 73;
 static integer c__5 = 5;
 static integer c__361 = 361;
 static integer c__181 = 181;
-static real c_b48 = 0.f;
-static real c_b49 = 360.f;
-static real c_b50 = -90.f;
-static real c_b51 = 90.f;
-static real c_b52 = 180.f;
+static real c_b50 = 0.f;
+static real c_b51 = 360.f;
+static real c_b52 = -90.f;
+static real c_b53 = 90.f;
+static real c_b54 = 180.f;
 static integer c__100 = 100;
 static integer c__72 = 72;
 static integer c__512 = 512;
 static integer c__2 = 2;
-static real c_b85 = -.5f;
+static real c_b87 = -.5f;
 
 /* ----------------------------------------------------------------------- */
 /*     TOMS OZONE DISTRIBUTION (MONTHLY MEAN CLIMATOLOGY) */
@@ -107,8 +107,9 @@ static real c_b85 = -.5f;
     o__1.ofm = "FORMATTED";
     o__1.oblnk = 0;
     f_open(&o__1);
-    swlstx_("LWAIT", &c_false, (ftnlen)5);
+    swlstx_("LWAIT", &c_true, (ftnlen)5);
     swlstx_("LWAIT0", &c_false, (ftnlen)6);
+    swlstx_("LALT", &c_false, (ftnlen)4);
     swistx_("IPOSX", &c__200, (ftnlen)5);
     swistx_("IPOSY", &c__200, (ftnlen)5);
     swistx_("IWIDTH", &c__800, (ftnlen)6);
@@ -123,7 +124,7 @@ static real c_b85 = -.5f;
     sglset_("LFULL", &c_true, (ftnlen)5);
     sglset_("LSOFTF", &c_false, (ftnlen)6);
     umlset_("LGLOBE", &c_true, (ftnlen)6);
-    slrat_(&c_b28, &c_b29);
+    slrat_(&c_b30, &c_b31);
     for (m = 1; m <= 12; ++m) {
 	s_rsfe(&io___9);
 	do_fio(&c__1, (char *)&mon, (ftnlen)sizeof(integer));
@@ -151,16 +152,16 @@ static real c_b85 = -.5f;
 /* L50: */
 	}
 	grfrm_();
-	grswnd_(&c_b48, &c_b49, &c_b50, &c_b51);
-	grsmpl_(&c_b52, &c_b51, &c_b48);
+	grswnd_(&c_b50, &c_b51, &c_b52, &c_b53);
+	grsmpl_(&c_b54, &c_b53, &c_b50);
 	i__1 = isgtrc_("HMR", (ftnlen)3);
 	grstrn_(&i__1);
 	umpfit_();
 	grstrf_();
-	slpwwr_(&c__1);
 	ueitlv_();
 	uestln_(tlevn, ipatn, &c__100);
 	uetonf_(gxdata, &c__361, &c__361, &c__181);
+	slpwwr_(&c__1);
 	umpgrd_();
 	umplim_();
 	umpmap_("coast_world", (ftnlen)11);
@@ -257,11 +258,11 @@ static real c_b85 = -.5f;
 	nn = *nx;
     }
     i__1 = *nx + 1;
-    rset0_(y, &i__1, &c__1, &c_b48);
+    rset0_(y, &i__1, &c__1, &c_b50);
     i__1 = (*maxwn << 1) + 1;
     vrset_(fc, y, &i__1, &c__1, &c__1);
-    rmlt0_(&y[1], maxwn, &c__2, &c_b29);
-    rmlt0_(&y[2], maxwn, &c__2, &c_b85);
+    rmlt0_(&y[1], maxwn, &c__2, &c_b31);
+    rmlt0_(&y[2], maxwn, &c__2, &c_b87);
     rfftb_(nx, y, wsave);
     vrset_(y, &x[1], nx, &c__1, &c__1);
     return 0;
