@@ -1,6 +1,13 @@
-/* src/grph1/szpack/szpipl.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -35,7 +42,7 @@ static real c_b2 = 1e-5f;
     static integer nn;
     static real dx, dy, xx0, xx1, yy0, yy1, dxx, dyy;
     static integer nend;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     static logical lint;
     extern logical lreqa_(real *, real *, real *);
 
@@ -51,7 +58,7 @@ static real c_b2 = 1e-5f;
     if (*mode == 0) {
 	lint = szbls1_1.llnint;
     } else if (*mode == 1) {
-	r__1 = dabs(*y0);
+	r__1 = abs(*y0);
 	r__2 = pi / 2;
 	lint = szbls1_1.llnint && ! (lreqa_(y0, y1, &c_b2) && lreqa_(&r__1, &
 		r__2, &c_b2));
@@ -72,8 +79,8 @@ static real c_b2 = 1e-5f;
     dx = *x1 - *x0;
     dy = *y1 - *y0;
 /* Computing MAX */
-    i__1 = (r__1 = dx / szbls1_1.rdxr, (integer) dabs(r__1)), i__2 = (r__2 = 
-	    dy / szbls1_1.rdyr, (integer) dabs(r__2));
+    i__1 = (r__1 = dx / szbls1_1.rdxr, (integer) abs(r__1)), i__2 = (r__2 = 
+	    dy / szbls1_1.rdyr, (integer) abs(r__2));
     nend = max(i__1,i__2) + 1;
     if (nend >= 2) {
 	dxx = dx / nend;
