@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfhmr.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -23,7 +30,7 @@
     /* Local variables */
     static real cf, rr, xx, yy, phi, rna, sqa, xlm2, cphi;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
 
     switch(n__) {
 	case 1: goto L_mpihmr;
@@ -46,10 +53,10 @@ L_mpihmr:
     if (rr <= 1.f) {
 	sqa = sqrt(2 - rr);
 	yy = sqa * *y / 1.4142136f;
-	if (dabs(yy) <= 1.f) {
+	if (abs(yy) <= 1.f) {
 	    phi = asin(yy);
 	    xx = *x * sqa / 2 / 1.4142136f / cos(phi);
-	    if (dabs(xx) <= 1.f) {
+	    if (abs(xx) <= 1.f) {
 		*xlon = asin(xx) * 2;
 		*ylat = phi;
 		return 0;
