@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -35,8 +35,9 @@
 	     real *, real *, real *, real *, real *, real *, real *, real *, 
 	    real *), shfwga_(integer *, integer *, integer *, integer *, 
 	    integer *, real *, real *, real *, real *), sholap_(integer *, 
-	    integer *, real *, real *), shfwgj_(integer *, integer *, integer 
-	    *, integer *, real *, real *, real *, real *), shfwgm_(integer *, 
+	    integer *, real *, real *), msgdmp_(char *, char *, char *, 
+	    ftnlen, ftnlen, ftnlen), shfwgj_(integer *, integer *, integer *, 
+	    integer *, real *, real *, real *, real *), shfwgm_(integer *, 
 	    integer *, integer *, real *, real *, real *, real *, real *), 
 	    shinit_(integer *, integer *, integer *, real *, real *, real *, 
 	    real *, real *, real *, real *, real *, real *, real *, real *, 
@@ -140,6 +141,14 @@
 /* ---------------------------------------------------------------------- */
 
 L_shtint:
+    if (*im < *mm + 1) {
+	msgdmp_("E", "SHTLIB", "IM MUST BE IM >= MM+1", (ftnlen)1, (ftnlen)6, 
+		(ftnlen)21);
+    }
+    if (*jm < (*mm + 1) / 2) {
+	msgdmp_("E", "SHTLIB", "JM MUST BE JM >= (MM+1)/2", (ftnlen)1, (
+		ftnlen)6, (ftnlen)25);
+    }
     ny = *jm + 1;
     nyw = *jm + 1;
     nys = *jm + 1;
