@@ -1,6 +1,13 @@
-/* src/math2/vstlib/vs2int.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -37,10 +44,10 @@ static integer c__0 = 0;
 	}
     wz_dim1 = *ix;
     wz_dim2 = *iy;
-    wz_offset = 1 + wz_dim1 * (1 + wz_dim2 * 1);
+    wz_offset = 1 + wz_dim1 * (1 + wz_dim2);
     wz -= wz_offset;
     nw_dim1 = *ix;
-    nw_offset = 1 + nw_dim1 * 1;
+    nw_offset = 1 + nw_dim1;
     nw -= nw_offset;
     if (y) {
 	--y;
